changeset 8802:c5a6db81842b

Avoid a test failure on mingw.
author Bruno Haible <bruno@clisp.org>
date Sat, 05 May 2007 11:41:20 +0000
parents 3d5ee33e5323
children 6c1d98929550
files ChangeLog tests/test-argp-2.sh
diffstat 2 files changed, 7 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2007-05-01  Bruno Haible  <bruno@clisp.org>
+
+	* tests/test-argp-2.sh (func_compare): Drop .exe suffix.
+
 2007-05-03  Paul Eggert  <eggert@cs.ucla.edu>
 
 	* m4/d-ino.m4 (gl_CHECK_TYPE_STRUCT_DIRENT_D_INO): Use better
--- a/tests/test-argp-2.sh
+++ b/tests/test-argp-2.sh
@@ -23,9 +23,11 @@
 ERR=0
 
 func_compare() {
 # If argp was compiled without base_name, it will display full program name
   sed '1{
          s,: [^ ]*/test-argp,: test-argp,
+         s,: test-argp\.exe,: test-argp,
         }' | diff -c $TMP -
 }
@@ -23,9 +23,11 @@
 
 func_compare() {
-# If argp was compiled without base_name, it will display full program name
+# If argp was compiled without base_name, it will display full program name.
+# If run on mingw, it will display the program name with a .exe suffix.
   sed '1{
          s,: [^ ]*/test-argp,: test-argp,